# remirepo/fedora spec file for php-tedivm-jshrink
#
# Copyright (c) 2015-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%bcond_without tests

%global gh_commit    8dd2fd54293e94fa1536c3c66700c707d814e043
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     tedious
#global gh_date      20150820
%global gh_project   JShrink
%global c_vendor     tedivm
%global c_project    jshrink
%global psr0         JShrink

Name:           php-%{c_vendor}-%{c_project}
Version:        1.6.1
Release:        1%{?gh_date?%{gh_date}git%{gh_short}}%{?dist}
Summary:        Javascript Minifier built in PHP

License:        BSD-3-Clause
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        %{name}-%{version}-%{?gh_short}.tgz
Source1:        makesrc.sh

BuildArch:      noarch
%if %{with tests}
BuildRequires:  php(language) >= 8.0
BuildRequires:  php-date
BuildRequires:  php-pcre
BuildRequires:  php-spl
# For tests, from composer.json "require-dev": {
#      "phpunit/phpunit": "^9|^10",
#      "friendsofphp/php-cs-fixer": "^3.14",
#      "php-coveralls/php-coveralls": "^2.5.0"
BuildRequires:  phpunit9
%endif
# For autoloader
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#    "php": "^8.0"
Requires:       php(language) >= 8.0
# From phpcompatinfo report for 1.1.0
Requires:       php-date
Requires:       php-pcre
Requires:       php-spl
# Autoloader
Requires:       php-composer(fedora/autoloader)

# Composer
Provides:       php-composer(%{c_vendor}/%{c_project}) = %{version}


%description
JShrink is a php class that minifies javascript so that it can be delivered
to the client quicker. This code can be used by any product looking to minify
their javascript on the fly (although caching the results is suggested for
performance reasons). Unlike many other products this is not a port into php
but a native application, resulting in better performance.

To use this library, you just have to add, in your project:
  require_once '%{_datadir}/php/%{psr0}/autoload.php';


%prep
%setup -q -n %{gh_project}-%{gh_commit}


%build
phpab --template fedora --output src/%{psr0}/autoload.php src/%{psr0}


%install
mkdir -p     %{buildroot}%{_datadir}/php
cp -pr src/* %{buildroot}%{_datadir}/php


%check
%if %{with tests}
mkdir vendor
cat << 'EOF' | tee tests/bootstrap.php
<?php
require '%{buildroot}%{_datadir}/php/%{psr0}/autoload.php';
EOF

: Run upstream test suite
ret=0
for cmd in php php80 php81 php82; do
  if which $cmd; then
   $cmd %{_bindir}/phpunit9 \
     --no-coverage || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
# remirepo:1
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc composer.json
%doc *.md
%{_datadir}/php/%{psr0}


%changelog
* Mon Mar  6 2023 Remi Collet <remi@remirepo.net> - 1.6.1-1
- update to 1.6.1

* Thu Apr  1 2021 Remi Collet <remi@remirepo.net> - 1.4.0-1
- update to 1.4.0
- switch to phpunit7

* Mon Sep  7 2020 Remi Collet <remi@remirepo.net> - 1.3.3-1
- update to 1.3.3
- raise dependency on PHP 5.6
- switch to classmap autoloader
- switch to phpunit6

* Tue Oct 27 2015 Remi Collet <remi@fedoraproject.org> - 1.1.0-1
- initial package
